==> mingw-w64-freecad-0.21.2-5.src.tar.zst: FreeCAD-0.21.2/src/Mod/TechDraw/Gui/DlgPrefsTechDrawAdvancedImp.h <==
 /**************************************************************************
 *   Copyright (c) 2015 FreeCAD Developers                                 *
 *   Author: WandererFan <wandererfan@gmail.com>                           *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef DRAWINGGUI_DLGPREFSTECHDRAWIMPADVANCED_H
#define DRAWINGGUI_DLGPREFSTECHDRAWIMPADVANCED_H

#include <Gui/PropertyPage.h>
#include <Mod/TechDraw/TechDrawGlobal.h>

#include <memory>


namespace TechDrawGui {
class Ui_DlgPrefsTechDrawAdvancedImp;

class DlgPrefsTechDrawAdvancedImp : public Gui::Dialog::PreferencePage
{
    Q_OBJECT

public:
    explicit DlgPrefsTechDrawAdvancedImp( QWidget* parent = nullptr );
    ~DlgPrefsTechDrawAdvancedImp() override;

protected:
    void saveSettings() override;
    void loadSettings() override;
    void changeEvent(QEvent *e) override;

private:
    std::unique_ptr<Ui_DlgPrefsTechDrawAdvancedImp> ui;
};

} // namespace TechDrawGui

#endif // DRAWINGGUI_DLGPREFSTECHDRAWIMPADVANCED_H

==> mingw-w64-freecad-1.0.0-3.src.tar.zst: FreeCAD-1.0.0/src/Mod/TechDraw/Gui/DlgPrefsTechDrawAdvancedImp.h <==
 /**************************************************************************
 *   Copyright (c) 2015 FreeCAD Developers                                 *
 *   Author: WandererFan <wandererfan@gmail.com>                           *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef DRAWINGGUI_DLGPREFSTECHDRAWIMPADVANCED_H
#define DRAWINGGUI_DLGPREFSTECHDRAWIMPADVANCED_H

#include <Gui/PropertyPage.h>
#include <Mod/TechDraw/TechDrawGlobal.h>

#include <memory>


namespace TechDrawGui {
class Ui_DlgPrefsTechDrawAdvancedImp;

class DlgPrefsTechDrawAdvancedImp : public Gui::Dialog::PreferencePage
{
    Q_OBJECT

public:
    explicit DlgPrefsTechDrawAdvancedImp( QWidget* parent = nullptr );
    ~DlgPrefsTechDrawAdvancedImp() override;

protected:
    void saveSettings() override;
    void loadSettings() override;
    void changeEvent(QEvent *event) override;

    void loadBalloonOverride();
    void saveBalloonOverride();

    void clearBalloonOptions();

    static bool flagsContainValue(uint flags, uint value);

    void makeBalloonBoxConnections();
    void slotBalloonBoxChecked();
    void enableBalloonOptions(bool newState);


private:
    std::unique_ptr<Ui_DlgPrefsTechDrawAdvancedImp> ui;
};

} // namespace TechDrawGui

#endif // DRAWINGGUI_DLGPREFSTECHDRAWIMPADVANCED_H
